slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPSetType

Selects the particular solver to be used in the NEP object.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPSetType(NEP nep,NEPType type)

Logically Collective on nep

### Input Parameters

| nep | - the nonlinear eigensolver context
| type | - a known method

### Options Database Key

| -nep_type <method> | - Sets the method; use -help for a list of available methods

### Notes

See "slepc/include/slepcnep.h" for available methods.

Normally, it is best to use the NEPSetFromOptions() command and then set the NEP type from the options database rather than by using this routine. Using the options database provides the user with maximum flexibility in evaluating the different available methods. The NEPSetType() routine is provided for those situations where it is necessary to set the iterative solver independently of the command line or options database.

### See Also

NEPType

### Level

intermediate

### Location

src/nep/interface/nepbasic.c

### Examples

src/nep/tutorials/ex21.c.html
src/nep/tutorials/ex27.c.html
src/nep/tutorials/ex27f90.F90.html
src/nep/tutorials/ex42.c.html
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages